screen = {
  width = love.graphics.getWidth(),
  height = love.graphics.getHeight()
}
GRAVITY =  screen.height * 3

local player = require 'player'
local wall = require 'wall'

function love.load()
  player:initialize(screen.width/4, 0)
end

function love.update(dt)
  player:update(dt)
  wall:update(dt)
  
  -- collision, loop through walls
  for i,v in ipairs(wall.array) do
    for _,s in ipairs(v) do
      if checkCollision(player.x, player.y, player.size, player.size, s.x, s.y, s.width, s.height) then
        player.collision = true
      else
        player.collision = false
      end
    end    
  end
end

function love.draw()  
  wall:draw()
  player:draw()
end

function love.keypressed(key)
  if key == 'escape' then
    love.event.quit()
  elseif key == ' ' then
    player:flap()
  end  
end

--[[ AABB Collision detection function.
Returns true if two boxes overlap, false if they don't
x1,y1 are the left-top coords of the first box, while w1,h1 are its width and height
x2,y2,w2 & h2 are the same, but for the second box ]]
function checkCollision(x1,y1,w1,h1, x2,y2,w2,h2)
  return x1 < x2+w2 and -- The left side of R1 is NOT to the right of the right side of R2
         x2 < x1+w1 and -- The left side of R2 is NOT to the right of the right side of R1
         y1 < y2+h2 and -- The top of R1 is NOT below the bottom of R2
         y2 < y1+h1 -- The top of R2 is NOT below the bottom of R1
end